@@ -1,7 +1,7 @@
 from configparser import ConfigParser
 from pathlib import Path
 from typing import Any, Dict, List
-from gcal_notifier.utils import CONFIG
+from gcal_notifier.utils import CONFIG, run_notify
 
 from gcsa.event import Event
 from gcsa.google_calendar import GoogleCalendar
@@ -38,6 +38,7 @@ class SimpleGCalendarGetter:
             else:
                 label = params["name"]
             self.calendars[params["name"]] = self.make_conn(
+                                                name=params["name"],
                                                 **conn_params
                                             ).get_events(**self.general_params)
             new_cal_params[label] = params
@@ -62,11 +63,13 @@ class SimpleGCalendarGetter:
 
     @staticmethod
     def make_conn(
+        name: str,
         calendar: str = "primary",
         credentials: Path = CONFIG / "default" / "credentials.json"
     ) -> GoogleCalendar:
         try:
             return GoogleCalendar(calendar=calendar, credentials_path=credentials)
         except RefreshError:
-            (CONFIG/"token.pickle").unlink()
+            (credentials.parent / "token.pickle").unlink()
+            run_notify(f'notify-send -u critical -a GoogleCalendar {calendar} "You have to authorize the credentials inside {credentials} again!"')
             return GoogleCalendar(calendar=calendar, credentials_path=credentials)
